@@ -6,16 +6,16 @@
 #' at or beyond a Minimally Important Difference (MID).
 #' It is designed to fail gracefully if no window given, and to
 #' give some useful labels about the windows / range used.
-#' Intended for use internally as part of \code{\link{brmsmargins}}.
+#' Intended for use internally as part of [brmsmargins()].
 #'
 #' @param x A vector of values to evaluate. Required.
 #' @param window An optional numeric vector giving a window.
 #' @param within A logical value indicating whether to calculate the
-#'   percentage within the window (if \code{TRUE}) or the
-#'   percentage at or outside the window (if \code{FALSE}).
-#'   Defaults to \code{TRUE}.
-#' @return A list with the \code{Window}, if specified else \code{NULL},
-#'   the \code{Percent} of observations, and a \code{Label} specifying the
+#'   percentage within the window (if `TRUE`) or the
+#'   percentage at or outside the window (if `FALSE`).
+#'   Defaults to `TRUE`.
+#' @return A list with the `Window`, if specified else `NULL`,
+#'   the `Percent` of observations, and a `Label` specifying the
 #'   exact window used in human readable format.
 #' @keywords internal
 #' @importFrom extraoperators %e%
@@ -53,7 +53,7 @@
 #'
 #' Returns a summary of a posterior distribution for a single
 #' parameter / value. It is based on personal preference. Notably, it does not
-#' only use \code{bayestestR::describe_posterior}, an excellent function,
+#' only use [bayestestR::describe_posterior()], an excellent function,
 #' because of the desire to also describe the percentage of the full posterior
 #' distribution that is at or exceeding the value of a
 #' Minimally Important Difference (MID). MIDs are used in clinical studies with outcome
@@ -63,37 +63,35 @@
 #'
 #' @param x The posterior distribution of a parameter
 #' @param CI A numeric value indicating the desired width of the credible interval.
-#'   Defaults to \code{0.99} currently, but this is subject to change.
+#'   Defaults to `0.99` currently, but this is subject to change.
 #'   a 99% interval was chosen as the default as there have been recent arguments
 #'   made in the realm of meta science that there are, essentially, too many
-#'   false positives and that many of the \dQuote{findings} in science are not able
+#'   false positives and that many of the "findings" in science are not able
 #'   to be replicated.
 #'   In any case, users should ideally specify a desired CI width, and not rely on
 #'   defaults.
 #' @param CIType A character string indicating the type of credible interval, passed on
-#'   to the \code{\link[bayestestR]{ci}} function as the method for CIs.
-#' @param ROPE Either left as \code{NULL}, the default, or a numeric vector of
+#'   to the [bayestestR::ci()] function as the method for CIs.
+#' @param ROPE Either left as `NULL`, the default, or a numeric vector of
 #'   length 2, specifying the lower and upper thresholds for the
 #'   Region of Practical Equivalence (ROPE).
-#' @param MID Either left as \code{NULL}, the default, or a numeric vector of
-#'   length 2, specifying the lower and upper thresholds for a 
+#' @param MID Either left as `NULL`, the default, or a numeric vector of
+#'   length 2, specifying the lower and upper thresholds for a
 #'   Minimally Important Difference (MID). Unlike the ROPE, percentages for
 #'   the MID are calculated as at or exceeding the bounds specified by this
 #'   argument, whereas the ROPE is the percentage of the posterior at or inside
 #'   the bounds specified.
-#' @return A \code{data.table} with the mean, \code{M}
-#' \describe{
-#'   \item{M}{the mean of the posterior samples}
-#'   \item{Mdn}{the median of the posterior samples}
-#'   \item{LL}{the lower limit of the credible interval}
-#'   \item{UL}{the upper limit of the credible interval}
-#'   \item{PercentROPE}{the percentage of posterior samples falling into the ROPE}
-#'   \item{PercentMID}{the percentage of posterior samples falling at or beyond the MID}
-#'   \item{CI}{the width of the credible interval used}
-#'   \item{CIType}{the type of credible interval used (e.g., highest density interval)}
-#'   \item{ROPE}{a label describing the values included in the ROPE}
-#'   \item{MID}{a label describing the values included in the MID}
-#' }
+#' @return A `data.table` with:
+#' - `M` the mean of the posterior samples
+#' - `Mdn` the median of the posterior samples
+#' - `LL` the lower limit of the credible interval
+#' - `UL` the upper limit of the credible interval
+#' - `PercentROPE` the percentage of posterior samples falling into the ROPE
+#' - `PercentMID` the percentage of posterior samples falling at or beyond the MID
+#' - `CI` the width of the credible interval used
+#' - `CIType` the type of credible interval used (e.g., highest density interval)
+#' - `ROPE` a label describing the values included in the ROPE
+#' - `MID` a label describing the values included in the MID
 #' @export
 #' @importFrom bayestestR ci
 #' @importFrom data.table data.table
@@ -159,12 +157,12 @@ bsummary <- function(x, CI = 0.99, CIType = "HDI", ROPE = NULL, MID = NULL) {
 #'
 #' Internal utility function confirm that an object
 #'   has the attributes needed to be used as data.
-#' Currently it should be a \code{tbl},
-#'   \code{data.frame}, or \code{data.table}.
+#' Currently it should be a `tbl`,
+#'   `data.frame`, or `data.table`.
 #'
 #' @param x An object to be evaluated.
 #' @param requireNames A logical, whether names are
-#'   required. Defaults to \code{TRUE}
+#'   required. Defaults to `TRUE`
 #' @return An empty string if no issues. Otherwise, a non zero
 #'   string with warning/error messages.
 #' @keywords internal
@@ -199,14 +197,14 @@ bsummary <- function(x, CI = 0.99, CIType = "HDI", ROPE = NULL, MID = NULL) {
   return(out)
 }
 
-#' Check a \code{brmsfit} Object has Random Effects
+#' Check a [brms::brmsfit-class] Object has Random Effects
 #'
-#' Internal utility function to check whether a \code{brmsfit}
+#' Internal utility function to check whether a [brms::brmsfit-class]
 #' object has any random effects or not.
 #'
 #' @param object An object to be evaluated.
-#' @return \code{TRUE} if any random effects present.
-#'   \code{FALSE} if no random effects present.
+#' @return `TRUE` if any random effects present.
+#'   `FALSE` if no random effects present.
 #' @keywords internal
 is.random <- function(object) {
   .assertbrmsfit(object)
@@ -214,12 +212,12 @@ is.random <- function(object) {
   isTRUE(nrow(object$ranef) >= 1L)
 }
 
-#' Extract the Link from a \code{brms} Model
+#' Extract the Link from a `brms` Model
 #'
-#' Internal utility function to take a \code{brmsfit} object
-#' and extract the link for a specific \code{dpar}.
+#' Internal utility function to take a [brms::brmsfit-class] object
+#' and extract the link for a specific brms `dpar`.
 #'
-#' @param object A \code{brmsfit} class model object.
+#' @param object A [brms::brmsfit-class] model object.
 #' @param dpar The dpar for which the link should be extracted.
 #' @return A character string, the link.
 #' @keywords internal
@@ -248,16 +246,14 @@ is.random <- function(object) {
 #' and returns a list with all the options needed to execute the desired
 #' options in [prediction()].
 #'
-#' @param link The link named in a \code{brmsfit} object
+#' @param link The link named in a [brms::brmsfit-class] object
 #' @param effects A character string, the type of effect desired
 #' @param backtrans A character string, the type of back transformation
 #' @return A list with eight elements.
-#' \describe{
-#'   \item{scale}{A character string giving the argument to be passed to [fitted()].}
-#'   \item{ilink}{A character string giving the name of the inverse link function.}
-#'   \item{ifun}{Inverse link function as an \code{R} function.}
-#'   \item{ilinknum}{An integer giving the inverse link / transformation to be applied in [integratere()], needed as this is a C++ function and cannot use the \code{R} based inverse link function.}
-#' }
+#'   - scale A character string giving the argument to be passed to [fitted()].
+#'   - ilink A character string giving the name of the inverse link function.
+#'   - ifun Inverse link function as an `R` function.
+#'   - ilinknum An integer giving the inverse link / transformation to be applied in [integratere()], needed as this is a C++ function and cannot use the `R` based inverse link function.
 #' @importFrom stats plogis qlogis
 #' @keywords internal
 .links <- function(link,
@@ -283,19 +279,14 @@ is.random <- function(object) {
     ## predictions on the original response scale
     ## in this case we need to proceed differently depending on
     ## the 'effect' argument
-    if (isTRUE(link == "identity")) {
-      inverselink <- "identity"
-    } else if (isTRUE(link == "logit")) {
-      inverselink <- "invlogit"
-    } else if (isTRUE(link == "log")) {
-      inverselink <- "exp"
-    } else if (isTRUE(link == "sqrt")) {
-      inverselink <- "square"
-    } else if (isTRUE(link == "inverse")) {
-      inverselink <- "inverse"
-    } else {
-      inverselink <- "notsupported"
-    }
+    inverselink <- switch(link,
+      "identity" = "identity",
+      "logit"    = "invlogit",
+      "log"      = "exp",
+      "sqrt"     = "square",
+      "inverse"  = "inverse",
+      "notsupported"  # default if no match
+    )
 
     if (isTRUE(effects %in% c("fixedonly", "includeRE"))) {
       ## for both these 'effects' we can rely on fitted()
