@@ -2,6 +2,6 @@
 #define __integratemvn__
 
 #include <RcppArmadillo.h>
-arma::mat integratemvn(const arma::mat& X, const int k, const Rcpp::NumericVector& sd, const arma::mat& chol);
+arma::mat integratemvn(const arma::mat& X, const arma::uword&, const arma::rowvec& sd, const arma::mat& chol);
 
 #endif // __integratemvn__
