@@ -17,14 +17,9 @@ using namespace Rcpp;
 //' lmcpp(cbind(1, mtcars$hp, mtcars$am), as.matrix(mtcars[, c("mpg", "qsec")]))
 // [[Rcpp::export]]
 arma::mat lmcpp(const arma::mat& X, const arma::mat& y) {
-  int k = X.n_cols;
-  int n = y.n_cols;
-  
-  arma::mat B(k, n);
-  
-  for (int i = 0; i < n; i++) {
-    B.col(i) = solve(X, y.col(i));
-  }
-  
-  return(B);
+  arma::mat Q, R;
+  arma::qr_econ(Q, R, X);                 // X = Q * R, R upper-triangular
+  arma::mat QtY = Q.t() * y;              // Project all response columns at once
+  arma::mat B = arma::solve(trimatu(R), QtY, arma::solve_opts::fast); // Backsolve
+  return B;
 }
